# cGMP module, translated from Yang et al 2005

# Return kinetic parameters, constraints, and vector of volumes in each
# compartment (pL) (1 if gating variable, or in element corresponding to
# kappa)

# Based on Pan 2018 cardiac AP

import numpy as np

def kinetic_parameters(M, include_type2_reactions, dims, V):

    num_cols = dims['num_cols']
    num_rows = dims['num_rows']

    fkc = 1e6
    smr = 1e-3

    # both reactions (1: E5c, 2: PDE) are MM
    Km_PDE = 2 # [=] uM
    Vmax_E5c = 0.8520 # [=] 1/s
    E0_E5c = 0.05  # [=] uM    #GUESS
    kcat = [Vmax_E5c/E0_E5c, 0.0195]

    k1ap = fkc
    k1am = fkc # smr
    k1bp = kcat[0]
    k1bm = smr
    k2ap = fkc
    k2am = k2ap*Km_PDE - kcat[1]
    k2bp = kcat[1]
    k2bm = smr

    # Calculate bond graph constants from kinetic parameters
    # Note: units of kappa are fmol/s, units of K are fmol^-1
    kf = [k1ap,  # R_E5c [=]
          k1bp,  # R_E5c [=]
          k2ap,  # R_PDE [=]
          k2bp,  # R_PDE [=]
          ]

    kr = [
        k1am,
        k1bm,
        k2am,
        k2bm,
    ]

    k_kinetic = kf + kr

    # CONSTRAINTS
    N_cT = []
    K_C = []

    # volume vector
    # W = list(np.append([1] * num_cols, [V['V_myo']] * num_rows))
    W = [1] * num_cols + [V['V_myo']]*num_rows

    return (k_kinetic, N_cT, K_C, W)













